# mcp-network-jcd Development Guidelines

Auto-generated from all feature plans. Last updated: 2026-01-30

## Active Technologies

- Python 3.12 + mcp (official Python SDK with FastMCP), netmiko (SSH to network devices) (001-paloalto-ssh-tool)

## Project Structure

```text
src/
tests/
```

## Commands

cd src [ONLY COMMANDS FOR ACTIVE TECHNOLOGIES][ONLY COMMANDS FOR ACTIVE TECHNOLOGIES] pytest [ONLY COMMANDS FOR ACTIVE TECHNOLOGIES][ONLY COMMANDS FOR ACTIVE TECHNOLOGIES] ruff check .

## Code Style

Python 3.12: Follow standard conventions

## Recent Changes

- 001-paloalto-ssh-tool: Added Python 3.12 + mcp (official Python SDK with FastMCP), netmiko (SSH to network devices)

<!-- MANUAL ADDITIONS START -->
<!-- MANUAL ADDITIONS END -->
